# SPyQR
A bad package for bad Romans

SPyQR is an inclusive python project that dreams of allowing all backgrounds to be able to program in python, even
if all you speak is ancient Latin. <3

## Install SPyQR
```!pip install SPyQR==0.0.1```
